###########
User Guide
###########

In the following sections you can find general information about energy systems modeling, and 
the detailed description of the classes, methods and functionalities of FINE. 

.. toctree::
    :maxdepth: 1
    :caption: Contents:

    componentsIntroDoc
    structureOfFINEDoc
    tutorialDoc
